@@ -84,6 +84,7 @@ static security_context_t prev_context=NULL;
 #include "yppasswd.h"
 #include "md5.h"
 #include "support.h"
+#include "bigcrypt.h"
 
 #if !((__GLIBC__ == 2) && (__GLIBC_MINOR__ >= 1))
 extern int getrpcport(const char *host, unsigned long prognum,
@@ -99,8 +100,6 @@ extern int getrpcport(const char *host, unsigned long prognum,
 # include "./lckpwdf.-c"
 #endif
 
-extern char *bigcrypt(const char *key, const char *salt);
-
 /*
    How it works:
    Gets in username (has to be done) from the calling program
@@ -310,7 +309,7 @@ static int _unix_run_shadow_binary(pam_handle_t *pamh, unsigned int ctrl, const
 	retval = PAM_AUTH_ERR;
     }
 
-    if (sighandler != NULL) {
+    if (sighandler != SIG_ERR) {
         (void) signal(SIGCHLD, sighandler);   /* restore old signal handler */
     }
 
@@ -471,8 +470,8 @@ static int save_old_password(pam_handle_t *pamh,
 	    err = 1;
 	} else {
 	    pass = crypt_md5_wrapper(oldpass);
-	    snprintf(nbuf, sizeof(nbuf), "%s:%d:1:%s\n",
-		     forwho, pwd->pw_uid, pass);
+	    snprintf(nbuf, sizeof(nbuf), "%s:%lu:1:%s\n",
+		     forwho, (unsigned long)pwd->pw_uid, pass);
 	    _pam_delete(pass);
 	    if (fputs(nbuf, pwfile) < 0) {
 		err = 1;
@@ -764,7 +763,7 @@ static int _do_setpass(pam_handle_t* pamh, const char *forwho,
 		struct yppasswd yppwd;
 		CLIENT *clnt;
 		int status;
-		int err = 0;
+		enum clnt_stat err;
 
 		/* Unlock passwd file to avoid deadlock */
 #ifdef USE_LCKPWDF
